@@ -172,7 +172,7 @@ static command_rec ssl_cmds[] = {
       "SSL CA Certificate file (PEM encoded) [taken from SSL_CERT_FILE if absent]" },
     { "SSLVerifyDepth", cmd_PolySetSlotInt,
       (void *)XtOffsetOf(SSLConfigRec, nVerifyDepth), RSRC_CONF, TAKE1,
-      "SSL Client verify depth (default 0)" },
+      "SSL Client verify depth (default 1)" },
     { "SSLVerifyClient", cmd_SSLVerifyClient,
       NULL, RSRC_CONF, TAKE1,
       "SSL Verify client type (none, optional, require, optional_no_ca)" },
@@ -202,7 +202,7 @@ static command_rec ssl_cmds[] = {
       "SSL Session Cache server TCP port number" },
     { "SSLSessionCacheTimeout", cmd_PolySetSlotInt,
       (void *)XtOffsetOf(SSLConfigRec, tSessionCacheTimeout), RSRC_CONF, TAKE1,
-      "SSL Session Cache object lifetime in seconds" },
+      "SSL Session Cache object lifetime in seconds (default: 300s)" },
     { NULL },
 };
 
@@ -252,10 +252,10 @@ static void *config_server_create(pool *p, server_rec *s)
     rec->szCACertificateFile  = NULL;
     rec->szLogFile            = NULL;
     rec->szReqCiphers         = NULL;
-    rec->nVerifyDepth         = 0;
+    rec->nVerifyDepth         = UNSET;
     rec->nVerifyClient        = VERIFY_UNSET; /* Will become VERIFY_NONE */
     rec->bFakeBasicAuth       = UNSET;        /* Will become FALSE */
-    rec->tSessionCacheTimeout = 0;
+    rec->tSessionCacheTimeout = UNSET;
 
     rec->fileLogFile          = NULL;
     rec->px509Certificate     = NULL;
@@ -280,6 +280,7 @@ static void *config_server_merge(pool *p, void *basev, void *addv)
     cfgMergeString(szCACertificatePath);
     cfgMergeString(szCACertificateFile);
     cfgMergeString(szLogFile);
+    cfgMergeString(szReqCiphers);
     cfgMergeInt(nVerifyDepth);
     cfgMerge(nVerifyClient, VERIFY_UNSET);
     cfgMergeBool(bFakeBasicAuth);
@@ -542,6 +543,10 @@ static void init_Module(server_rec *s, pool *p)
             pConfig->bDisabled = FALSE;
         if (pConfig->nVerifyClient == VERIFY_UNSET)
             pConfig->nVerifyClient = VERIFY_NONE;
+        if (pConfig->nVerifyDepth == UNSET)
+            pConfig->nVerifyDepth = 1;
+        if (pConfig->tSessionCacheTimeout == UNSET)
+            pConfig->tSessionCacheTimeout = 300;
         if (pConfig->bFakeBasicAuth == UNSET)
             pConfig->bFakeBasicAuth = FALSE;
 
@@ -561,12 +566,6 @@ static void init_Module(server_rec *s, pool *p)
          * Now check for important parameters and the
          * possibility that the user forgot to set them.
          */
-        if (!pConfig->tSessionCacheTimeout) {
-            ap_log_error(APLOG_MARK, APLOG_NOERRNO|APLOG_ERR, s,
-                         "mod_ssl: No SSL Session Cache Timeout set [hint: SSLSessionCacheTimeout]");
-            ap_clear_pool(p);
-            exit(1);
-        }
         if (!pConfig->szCertificateFile) {
             ap_log_error(APLOG_MARK, APLOG_NOERRNO|APLOG_ERR, s,
                          "mod_ssl: No SSL Certificate set for server %s:%d [hint: SSLCertificateFile]",
@@ -910,7 +909,7 @@ static int init_VerifyFlags(SSLConfigRec *pConfig)
 
         if (ret <= 0) {
             ap_log_error(APLOG_MARK, APLOG_ERR|APLOG_NOERRNO, srvr,
-                         "mod_ssl: SSL_accept failed");
+                         "mod_ssl: SSL handshake failed");
             ssl_log_ssleay2apache(srvr);
             fb->flags |= B_EOF|B_EOUT;
             return FALSE;
@@ -1194,7 +1193,7 @@ static int ssl_callback_SSLVerify(int ok, X509_STORE_CTX *ctx)
         ssl_log_ssleay2apache(g_pCurrentConnection->server);
         g_pCurrentConnection->client->szClientX509 = NULL;
     }
-    if (depth >= pConfig->nVerifyDepth) {
+    if (depth > pConfig->nVerifyDepth) {
         ssl_log_own(pConfig, "Verify depth exceeded");
         ap_log_error(APLOG_MARK, APLOG_ERR | APLOG_NOERRNO,
                      g_pCurrentConnection->server, "mod_ssl: Verify depth exceeded");
