@@ -106,7 +106,7 @@
 #define cfgMergeTable(el)   new->el = ap_overlay_tables(p, add->el, base->el)
 #define cfgMergeString(el)  cfgMerge(el, NULL)
 #define cfgMergeBool(el)    cfgMerge(el, UNSET)
-#define cfgMergeInt(el)     cfgMerge(el, 0)
+#define cfgMergeInt(el)     cfgMerge(el, UNSET)
 
 #define mySrvConfig(srv) (SSLConfigRec *)ap_get_module_config(srv->module_config, &ssl_module)
 #define myDirConfig(req) (SSLDirConfigRec *)ap_get_module_config(req->per_dir_config, &ssl_module)
