@@ -172,7 +172,7 @@ static void ssl_gcache_WriteCommand(int nFD, enum Command eCommand)
     return;
 }
 
-void ssl_gcache_GlobalAdd(uchar *aucKey, int nKey, uchar *aucData,
+void ssl_gcache_GlobalAdd(UCHAR *aucKey, int nKey, UCHAR *aucData,
                     int nData, time_t tExpiresAt)
 {
     int nFD;
@@ -187,10 +187,10 @@ void ssl_gcache_GlobalAdd(uchar *aucKey, int nKey, uchar *aucData,
     return;
 }
 
-uchar *ssl_gcache_GlobalGet(uchar *aucKey, int nKey, int *pnData, time_t *ptExpiresAt)
+UCHAR *ssl_gcache_GlobalGet(UCHAR *aucKey, int nKey, int *pnData, time_t *ptExpiresAt)
 {
     int nFD;
-    uchar *ret;
+    UCHAR *ret;
 
     if ((nFD = ssl_gcache_OpenServer()) < 0) {
         *pnData = 0;
